// Persistence of Vision Ray Tracer Scene Description File
// File: karate.pov
// Vers: 3.6
// Desc:
// Date:
// Auth: Iacopo Mochi

// Standard pre-defined colors
//
#include "colors.inc"


// several different gold colors, finishes and textures
#include "golds.inc"

// various metal colors, finishes and textures
// brass, copper, chrome, silver
#include "metals.inc"

// various (mostly layered) wood textures
// T_Wood1 - T_Wood35
#include "woods.inc"
// a lot of stone textures
// T_Stone1 - T_Stone44
#include "stones.inc"

// atmospheric media can be generated by adding a media statement


camera {
  location <30, 16, -20>
  look_at <0.0, 4, -6>
  right x*image_width/image_height
  //aperture 1.0 // [0...N] larger is narrower depth of field (blurrier)
  //blur_samples 10 // number of rays per pixel for sampling
  //focal_point <0,0,0> // point that is in focus <X,Y,Z>
  //confidence 0.95 // [0...<1] when to move on while sampling (smaller is less accurate)
  //variance 1/200 // [0...1] how precise to calculate (smaller is more accurate)
}

// An area light (creates soft shadows)
// WARNING: This special light can significantly slow down rendering times!
light_source {
  0*x // light's position (translated below)
  color rgb 0.7 // light's color
  area_light
  <8, 0, 0> <0, 0, 8> // lights spread out across this distance (x * z)
  4, 4 // total number of lights in grid (4x*4z = 16 lights)
  adaptive 0 // 0,1,2,3...
  jitter // adds random softening of light
  circular // make the shape of the light circular
  orient // orient light
  media_interaction off
  translate <20, 15, -20> // <x y z> position of light
}

// create a regular point light source
light_source {
  0*x // light's position (translated below)
  color rgb <2,.5,.5> // light's color
  translate <-100, 80,100>
}

 // radiosity (global illumination) settings
global_settings {
  radiosity {
    pretrace_start 0.08 // start pretrace at this size
    pretrace_end 0.04 // end pretrace at this size
    count 35 // higher -> higher quality (1..1600) [35]
    nearest_count 5 // higher -> higher quality (1..10) [5]
    error_bound 1.8 // higher -> smoother, less accurate [1.8]
    recursion_limit 3 // how much interreflections are calculated (1..5+) [3]
    low_error_factor .5 // reduce error_bound during last pretrace step
    gray_threshold 0.0 // increase for weakening colors (0..1) [0]
    minimum_reuse 0.015 // reuse of old radiosity samples [0.015]
    brightness 1 // brightness of radiosity effects (0..1) [1]

    adc_bailout 0.01/2
    //normal on // take surface normals into account [off]
    //media on // take media into account [off]
    //save_file "file_name" // save radiosity data
    //load_file "file_name" // load saved radiosity data
    //always_sample off // turn sampling in final trace off [on]
    //max_sample 1.0 // maximum brightness of samples
  }
}



////////////////////////////////////////////////////////// O-HASHI
#declare sform=
intersection{
prism {
  conic_sweep
  cubic_spline
    39,
    25,
    11, // number of points
  <-0.3,-0.15>,<-0.3,0.15>,<-0.15,0.3>,<0.15,0.3>,<0.3,0.15>,
  <0.3,-0.15>,<0.15,-0.3>,<-0.15,-0.3>,<-0.3,-0.15>,<-0.3,0.15>,
  <-0.3,0>
  translate <0,-32,0>
  scale <0.015,1,0.015>
       }
sphere_sweep {
  linear_spline
  2,
  <0, 6, 0>, .4
  <0, -6, 0>, .4
            }
}
#declare hashi=
union{
object{sform}
object{sform
        rotate<0,180,0>}
        rotate<90,0,0>
texture{T_Wood10}
        rotate<-90,0,0>
}
///////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////// MOSCA

/////////ALA


#declare ala=
intersection{
        sphere{
                <0,0,0>,1
                scale <0.6,.1,2>
                rotate <0,45,0>
                }
        sphere{
                <-1.0,0,3.5>,4
                scale <1,.001,1>
                }
}
#declare segm1=
intersection{
        object{ala}
        sphere{<1.45,0,-3.5>,4}
                }

#declare segm2=
difference{
        object{ala}
        sphere{<2.18,0,-3.5>,4.5}
        sphere{<1.7,0,1>,0.8}
                }

#declare segm3=
intersection{
        object{segm2}
        sphere{<2.74,0,-3.3>,4.8}
                }


#declare segm1b=
        object{segm1
        scale <0.96,5,0.96>
        }
#declare segm2b=
        object{segm2
        scale <0.94,5,0.92>
        }
#declare segm3b=
        object{segm2
        scale <0.96,5,0.96>
        }
#declare alab=
        object{ala
        scale <0.96,5,0.96>
        }
        

#declare struttura=
union{
difference{
        object{segm1}
        object{segm1b}
}
difference{
        object{ala}
        object{alab}
}
difference{
        object{segm2}
        object{segm2b
                translate <0.03,0,0.07>}
}
difference{
        object{segm3}
        object{segm3
                translate <0.03,0,0>}
}
}


#declare wing=
union{
object{ala
        //texture{pigment{color rgb <2,2,2>}
        texture{pigment{color rgbt <1,1,1,.8>}
        normal { bumps 0.05 scale 0.05 }
        }}
object{struttura
        scale <1,0.9,1>
        texture{pigment{color Gray05}}}
sphere{<-1.1,0,-.5>,.1
        scale <1,0.9,1>
        texture{pigment{color Gray05}}}
        }
//occhio
#declare occhio=
sphere {
  <0, 0, 0>
  0.2
  scale <1,1.5,.6>
  texture{
        pigment{
                color rgb <.5,0,0>
                }
        }
}

#declare testa=
intersection{
        sphere {
                <0, 0, 0>
                .6
                scale <.8,.8,.5>
                }
        sphere {
                <0, .5, 0>
                .8
                scale <1,1,1>
                }
        sphere {
                <0, 0, -.6>
                .85
                scale <1,1,1>
                }
         texture{
                 pigment{
                        color rgb <.05,.05,0.1>
                         }
                 }
         scale <1.1,1.1,1.1>
                                
}

//retro
#declare corpo=
union{
        intersection{
                sphere{<0,0,0>,.5
                        scale<1,1,2.5>
                        rotate<5,0,0>
                        translate<0,-0.1,1>
                        }
                box{<1,1,-1>,<-1,-1,0>}
                texture{pigment{color Gray05}}
                }
         intersection{
                sphere{<0,0,0>,.5
                        scale<1.1,1.1,1.8>
                        rotate<12,0,0>
                        translate<0,-0.15,1>
                        }
                box{<1,1,0>,<-1,-1,1.5>}
                texture{pigment{color Gray10}}
                }
         intersection{
                sphere{<0,0,0>,.5
                        scale<1,1,2>
                        rotate<15,0,0>
                        translate<0,-0.2,1.3>
                        }
                box{<1,1,1>,<-1,-1,2>}
                texture{pigment{color Gray15}}
                }
        intersection{
                sphere{<0,0,0>,.51
                        scale<.9,.9,3>
                        rotate<20,0,0>
                        translate<0,-0.01,1>
                        }
                box{<1,1,1.8>,<-1,-1,2.5>}
                texture{pigment{color Gray20}}
                }
        sphere{<0,0,0>,.51
                        scale<.9,.6,.9>
                        rotate<00,0,0>
                        translate<0,-0.2,.5>
                        texture{pigment{color rgb <1,1,1>}}
                }
}





/*
intersection{
        object{corpo}
        sphere{<0,4.6,1.1>,5
        texture{pigment{color Coral}}
        }
        }
*/

#declare scudo=
intersection{
union{
sphere{<0,0,0>,0.35
        scale<1,1,0.4>
        texture{pigment{color Gray10}
        //finish{Shiny}
        }
        }
sphere{<0,0,0>,0.35
        scale<1,1,0.4>
        rotate<15,0,0>
        translate<0,0.0,0.05>
        texture{pigment{color Gray10}}
        }
sphere{<0,0,0>,0.3
        scale<1,1,0.4>
        rotate<30,0,0>
        translate<0,0.0,0.1>
        texture{pigment{color Gray10}
        //finish{Shiny}
        }
        }
}
sphere{<0,0.6,0>,1
        texture{pigment{color Gray10}}
        }

}

#declare zampa1=
union{
        sphere_sweep {
          //linear_spline // linear curve
          cubic_spline // alternative spline curves
          //b_spline
          5, // number of specified sphere positions
          <0, -0.8, 0>, .05
          <0, -0.9, 0>, .04
          <0.1, -.95, 0>,.025
          <0.5, -.9, 0>, .015
          <0.51, -.9, 0>, .015

          //tolerance 0.001 // optional
        }
          sphere_sweep {
          cubic_spline // alternative spline curves
          5,
          <0.5, -.89, 0>, .015
          <0.5, -.9, 0>, .013
          <0.52, -1, 0>, .013
          <0.6, -1.1, 0>, .013
          <0.6, -1.11, 0>, .013
          //tolerance 0.001 // optional
        }
          sphere_sweep {
          cubic_spline // alternative spline curves
          4,
          <0.55, -.89, 0>, .015
          <0.6, -1.1, 0>, .015
          <0.65, -1.15, 0>, .010
          <0.7, -1.17, 0>, .009
         
          //tolerance 0.001 // optional
        }
        sphere{<0,0,0>,0.010
                scale<3,1,1>
                rotate<0,0,-20>
                translate<0.67, -1.16, 0>
                }
        sphere{<0,0,0>,0.010
                scale<3,1,1>
                rotate<0,0,-15>
                translate<0.72, -1.175, 0>
                }
        sphere{<0,0,0>,0.010
                scale<3,1,1>
                rotate<0,0,-10>
                translate<0.77, -1.185, 0>
                }
        sphere{<0,0,0>,0.010
                scale<3,1,1>
                rotate<0,0,-5>
                translate<0.82, -1.190, 0>
                }
                                       
 }

//////////////////////
//pelo

#declare pelo=
              sphere_sweep{
              b_spline
              7,
              <0,-1.5,-2>,0.1
              <0,-1,-1.5>,0.1
              <0,-0.5,-1>,0.05
              <0,0,0>,0.03
              <0,0.4,1>,0.025
              <0,.6,2>,0.0125
              <0,.7,3>,0.006
              texture{pigment{color rgb <1,0,0>}}
              }
               
/////////////////////
               
#declare mosca=
union{
object{testa
        scale<1,1,1>
        rotate<0,0,0>
        translate<0,0,0>}
object{occhio
        translate <-0.2,0.35,.4>
        rotate <20,0,5>
        translate <0,0,-.7>}
object{occhio
        translate <0.2,0.35,.4>
        rotate <20,0,-5>
        translate <0,0,-.7>}
object{corpo
        scale<1,0.8,1>
        rotate<5,0,0>
        translate<0,0.1,1>
        scale<1,1,0.8>}
object{scudo
        scale<1.3,1.3,2.3>
        translate<0,0,0.5>
        scale<1,1,0.8>
        }
object{zampa1
        scale<2,2,2>
        rotate<0,30,0>
        translate<.2,1.4,0.8>
        texture{pigment{color Gray05}}
        }
object{zampa1
        scale<2,2,2>
        rotate<0,150,0>
        translate<-.2,1.4,0.8>
        texture{pigment{color Gray05}}
        }
object{zampa1
        scale<2,2,2>
        translate<.2,1.4,1.2>
        texture{pigment{color Gray05}}
        }
object{zampa1
        scale<2,2,2>
        rotate<0,180,0>
        translate<-.2,1.4,1.2>
        texture{pigment{color Gray05}}
        }
object{zampa1
        scale<2,2,2>
        rotate<0,-50,0>
        translate<.2,1.4,1.4>
        texture{pigment{color Gray05}}
        }
object{zampa1
        scale<2,2,2>
        rotate<0,230,0>
        translate<-.2,1.4,1.4>
        texture{pigment{color Gray05}}
        }

object{wing
        scale<1,1,1>
        rotate<20,-75,160>
        translate<0.55,0.3,1.75>}

object{wing
        scale<1,1,1>
        rotate<-20,-75,20>
        translate<-0.55,0.3,1.75>}
}
       
                  


                          
//////////////////////////////////////////////////////////

////////////////////////////////////////////////////////// SCODELLA
#declare tr=<1,-2,5>;
#declare f=5;
#declare conca=
         difference{
                    sphere{<0,0,0>,1}
                    plane{-y,0}
                    }
#declare scodella=
        union{
                difference{
                           object{conca}
                           sphere{<0,0,0>,0.95}
                          }
                difference{
                        cylinder{<0,-.9,0>,<0,-1.1,0>,0.4}
                        torus{1,0.3
                              translate <0,-1.1,0>
                              scale <0.5,1,0.5>
                              }
                        }
                torus{0.975,0.025
                        translate <0,0,0>}
                }
#declare riso=
        sphere{<0.0,0.0,0.0>,0.02
                scale <.5,1.5,.5>
                texture{pigment{color rgb <1.7,1.7,1.5>}}}
                                
//////////////////////////////////////////////////////////

////////////////////////////////////////////////////////// TAVOLO

#declare tav=
        box{<-10,-1,-10>,<10,1,10>}
        
#declare buco=
        box{<-4.25,-2,-8.5/38>,<4.25,2,8.5/38>
                scale<2/3,1,2/3>}
       
#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                translate<6.2,0,Count1*34/57+6.2>}
                        }                        
#declare Count1=Count1+1;
#end

#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                translate<-6.2,0,Count1*34/57-6.2>}
                        }
#declare Count1=Count1+1;
#end

#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                translate<6.2,0,-6.2+Count1*34/57>}
                        }
#declare Count1=Count1+1;
#end
       
#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                translate<-6.2,0,+6.2+Count1*34/57>}
                        }
#declare Count1=Count1+1;
#end
#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                translate<0,0,Count1*34/57>}
                        }

#declare Count1=Count1+1;
#end

#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                rotate<0,90,0>
                                translate<Count1*34/57-6.2,0,0>}
                        }
#declare Count1=Count1+1;
#end

#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                rotate<0,90,0>
                                translate<6.2+Count1*34/57,0,0>}
                        }
#declare Count1=Count1+1;
#end
         
#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                rotate<0,90,0>
                                translate<Count1*34/57,0,-6.2>}
                        }
#declare Count1=Count1+1;
#end

#declare Count1=-4.5;
#while (Count1<5.5)
        #declare tav=
                difference{
                        object{tav}
                        object{buco
                                rotate<0,90,0>
                                translate<Count1*34/57,0,6.2>}
                        }
#declare Count1=Count1+1;
#end

#declare tavolo=
        union{
                object{tav}
                box{<-10,-1,-10>,<-9,-7,-9>}
                box{<10,-1,10>,<9,-7,9>}
                box{<-10,-1,10>,<-9,-7,9>}
                box{<10,-1,-10>,<9,-7,-9>}
        texture{T_Wood16
                finish { reflection {.1}}}
        }
//////////////////////////////////////////////////////////

////////////////////////////////////////////////////////// O-CHA

#declare esterno=
lathe {
  cubic_spline // linear_spline | quadratic_spline | cubic_spline
  14, // number of points
  <1.2,-4.2>, <1.4,-4.1>, <1.9,-4>,<2.05,-3.5>, <2.025,-2.5>, <2.0,-1> ,
  <2.05,-0.5>, <2, 0>, <2.05, 0.5>, <2, 1>, <2.05, 1.5>,
  <2, 2>, <2, 2.5>, <2, 3>
  //scale <1,2,1>
}

#declare tazza=
        union{
                object{esterno}
                object{esterno
                        scale <0.95,0.99,0.950>}
                torus{1.95,0.05
                        translate <0,2.5,0>}
                cylinder{<0,-4.3,0>,<0,-4.1,0>,1.1}
                torus{1.3,0.2
                        translate <0,-4.2,0>}
                }
#declare tazza_p=
union{
        object{tazza
        scale <1,0.8,1>
        texture{pigment{gradient y
                                turbulence <0,0.5,0>
                                frequency 0.12
                                color_map {
                                                [0 color Yellow]
                                                [0.5 color Orange]
                                                [1 color Red]}
                         }
                        normal { bumps 0.1 scale 0.04 }
                        finish { phong 1 }
                        }
                        }
        cylinder{<0,-3.9,0>,<0,1.5,0>,1.95
        texture{pigment{color rgbt <0.3,0.2,0.1,.4>}
        finish { reflection {.15} ambient .2 diffuse .2 }
        }
        scale <1,0.8,1>
        interior{ior 1.33}
        }
        }
////////////////////////////////////////////////////////// stanza
#declare stanza=
        difference{
                difference{
                        box{<-40,-14.5,-40>,<40,20,40>}
                        box{<-37,-13.5,-37>,<37,19,37>}
                        }
                        union{
                              box{<-35,-5,-15>,<-45,12,35>}
                              box{<35,-5,30>,<-35,12,45>}
                              }
                
                texture{
                        pigment{
                                color rgb <0.9,0.9,0.6>
                                }
                         }
            }    
#declare mediabox=box{<-37,-13.5,-37>,<37,19,37>
pigment { rgbt 1 } hollow
   interior
   { media
     { scattering { 2, rgb<0.01,0.005,0.005> extinction 0.01 }
       samples 30,100
     }
   }
   }
/////////////////////////////////////////////////////////////
#declare mediacyl=cylinder{<0,-16,0>,<0,40,0>,43
pigment { rgbt 1 } hollow
   interior
   { media
     { scattering { 2, rgb<0.01,0.005,0.005> extinction 0.005 }
       samples 30,100
     }
   }
   }


////////////////////////////////////////////////////////// bamboo
#declare segmentob=
union{
intersection{
                sphere_sweep{
                      cubic_spline
                      5,
                      <0,3,0>,2
                      <0,2.5,0>,1.5
                      <0,0,0>,0.85
                      <0,-2.5,0>,1.5
                      <0,-3,0>,2
                      }
                 box{<-1,1.3,-1>,<1,-1.3,1>}
              
                texture{
                        pigment{
                                color rgb <0,.7,0>
                                }
                         }
            }
torus{1.14,0.02
        pigment{color rgb <0.5,0.5,0.1>}
        translate<0,1.3,0>
        }
        }
        #declare bamboo=object{segmentob}
        #declare Count2=1;
        #while (Count2<15)
               #declare bamboo=
               union{
               object{bamboo}
               object{segmentob
                      translate y*2.6*Count2}
                      }
               #declare Count2=Count2+1;
        #end
        
#declare foglia=
      intersection{
      cylinder{<0,0,0>,<0,0.01,0>,1
                scale<0.1,1,1>}
      cylinder{<0,0,-.5>,<0,0.02,-.5>,1
                scale<0.05,1,1>}          
                         }
/////////////////////////////////////////////////////////////

#declare ttx=6;
#declare ttz=0;

object{tavolo
        scale<1.5,1,1.5>
        rotate<0,-30,0>
        translate<5,-8.5,0>
        translate<-6,0,0>}

object{tazza_p
        translate <0,-4,-6>
        translate<ttx,0,ttz>}


object{hashi
        rotate <0,90,0>
        rotate <90,0,0>
        rotate <-0.7,0,0>
        translate <1,-1.63,5>
        translate<ttx,0,0>
        }
object{hashi
        rotate <90,0,0>
        rotate <0,4,0>
        rotate <-0.7,0,0>
        translate <-1,-1.63,5>
        translate<ttx,0,0>}

object{scodella
        scale <1,1,1,>*f
        translate tr
                        texture{pigment{gradient y
                                turbulence <0,0.5,0>
                                frequency 0.12
                                color_map {
                                                [0 color Yellow]
                                                [0.5 color Orange]
                                                [1 color Red]}
                         }
                        normal { bumps 0.1 scale 0.04 }
                        finish { phong 1 }
                        }                        
                        translate<ttx,0,0>
        }
        

#include "rand.inc"

#declare Count1=0; #declare seme=seed(0);
                 #while(Count1<50000)
                                                                      
                         #declare xx=(2*rand(seme)-1)*f;
                         #declare zz=(2*rand(seme)-1)*f;
                         #declare yy=(rand(seme)*0.1+0.9)*(1-(xx*xx+zz*zz)/25)+(sin(xx*xx/2+zz*zz/2+5*rand(seme)))/4;
                         #if ((zz*zz+xx*xx)<((yy)*(yy)*f*f*0.85))
                                object{riso
                                scale <1,1,1>*f
                                rotate <rand(seme),rand(seme),rand(seme)>*180
                                translate <xx+ttx,(yy-1.2)*f,zz>+tr}
                         #end
                  
                  #declare Count1=Count1+1;
                 #end
                


object{mosca
        scale <0.2,0.2,0.2>
        translate <-1.7+ttx,-1.5,-6>}
object{mosca
        scale <0.2,0.2,0.2>
        rotate <90,160,10>
        translate <3+ttx,-2.5,0.30>}

union{
object{hashi
        rotate<90,0,0>
        texture{T_Wood10
        finish{ambient .3}}
        rotate<-90,0,0>
        rotate<-40,0,0>
        translate<5,10.9,-11>
        }
object{hashi
        rotate<90,0,0>
        texture{T_Wood10
        finish{ambient .3}}
        rotate<-90,0,0>
        rotate<-45,0,0>
        translate<5,10.3,-11.8>
        }
          rotate<0,-10,0>
          translate<15,5,-10>
          }
object{mosca
        scale <0.2,0.2,0.2>
        rotate <40,-60,-45>
        rotate <0,0,0>
        translate <6.3,6.05,-6.3>
        translate<15,5,-10>}
object{mosca
        scale <0.2,0.2,0.2>
        rotate <40,-60,-45>
        rotate <0,-40,-30>
        translate <6.3,6.05,-6.3>
        translate<15,7,-8>}
object{mosca
        scale <0.2,0.2,0.2>
        rotate <40,-60,-45>
        rotate <-30,140,0>
        translate <6.3,6.05,-6.3>
        translate<14,4,-12>}                        

#declare c=1;#declare seme=seed(0);
#while (c<70000)
        #declare raggio=60+20*(2*rand(seme)-1);
        #declare angolo=rand(seme)*pi+pi/2;
        object{foglia
        scale <2,2,2>
        rotate<0,0,90>
        rotate<rand(seme)*5,rand(seme)*360,0>
        translate<70*(2*rand(seme)-1)*cos(angolo),-15.9+0.1*rand(seme),70*(2*rand(seme)-1)*sin(angolo)>
        #declare r=2*rand(seme)-1;#declare g=rand(seme);
        texture{
                        pigment{
                                color rgb <g+r/3,g,0>
                                }
                         }
        }        
        #declare c=c+1;
#end    

#declare c=1;#declare seme=seed(14);
#while (c<600)
        #declare raggio=60+20*(2*rand(seme)-1);
        #declare angolo=rand(seme)*pi+pi/2;
        object{bamboo
        scale<0.6,2,0.6>
        rotate<5*rand(seme),7*rand(seme),5*rand(seme)>
        
        //translate<-140+70*(2*rand(seme)-1),-16.5-rand(seme),70*(2*rand(seme)-1)+50>}
        translate<raggio*cos(angolo),-16.5-2*rand(seme),raggio*sin(angolo)>}
        #declare c=c+1;
#end         

object{mediacyl}

  sky_sphere {
    pigment {
      gradient y
      color_map {
        [ 0.001  color rgb <0,0,0>]
        [ 0.5  color rgb <0.2,0,0> ]
        [ 1  color rgb <0.1,0.05,0.05> ]
      }
    }
  }

// perspective (default) camera
